==> zio-aws-storagegateway_3-5.17.116.2-sources.jar: zio/aws/storagegateway/model/DisassociateFileSystemResponse.scala <==
package zio.aws.storagegateway.model
import zio.aws.storagegateway.model.primitives.FileSystemAssociationARN
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class DisassociateFileSystemResponse(
    fileSystemAssociationARN: Option[FileSystemAssociationARN] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.storagegateway.model.DisassociateFileSystemResponse = {
    import DisassociateFileSystemResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.storagegateway.model.DisassociateFileSystemResponse
      .builder()
      .optionallyWith(
        fileSystemAssociationARN.map(value =>
          FileSystemAssociationARN.unwrap(value): java.lang.String
        )
      )(_.fileSystemAssociationARN)
      .build()
  }
  def asReadOnly
      : zio.aws.storagegateway.model.DisassociateFileSystemResponse.ReadOnly =
    zio.aws.storagegateway.model.DisassociateFileSystemResponse
      .wrap(buildAwsValue())
}
object DisassociateFileSystemResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.storagegateway.model.DisassociateFileSystemResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.storagegateway.model.DisassociateFileSystemResponse =
      zio.aws.storagegateway.model.DisassociateFileSystemResponse(
        fileSystemAssociationARN.map(value => value)
      )
    def fileSystemAssociationARN: Option[FileSystemAssociationARN]
    def getFileSystemAssociationARN
        : ZIO[Any, AwsError, FileSystemAssociationARN] = AwsError
      .unwrapOptionField("fileSystemAssociationARN", fileSystemAssociationARN)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.storagegateway.model.DisassociateFileSystemResponse
  ) extends zio.aws.storagegateway.model.DisassociateFileSystemResponse.ReadOnly {
    override val fileSystemAssociationARN: Option[FileSystemAssociationARN] =
      scala
        .Option(impl.fileSystemAssociationARN())
        .map(value =>
          zio.aws.storagegateway.model.primitives
            .FileSystemAssociationARN(value)
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.storagegateway.model.DisassociateFileSystemResponse
  ): zio.aws.storagegateway.model.DisassociateFileSystemResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-storagegateway_3-5.17.206.1-sources.jar: zio/aws/storagegateway/model/DisassociateFileSystemResponse.scala <==
package zio.aws.storagegateway.model
import zio.aws.storagegateway.model.primitives.FileSystemAssociationARN
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class DisassociateFileSystemResponse(
    fileSystemAssociationARN: Optional[FileSystemAssociationARN] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.storagegateway.model.DisassociateFileSystemResponse = {
    import DisassociateFileSystemResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.storagegateway.model.DisassociateFileSystemResponse
      .builder()
      .optionallyWith(
        fileSystemAssociationARN.map(value =>
          FileSystemAssociationARN.unwrap(value): java.lang.String
        )
      )(_.fileSystemAssociationARN)
      .build()
  }
  def asReadOnly
      : zio.aws.storagegateway.model.DisassociateFileSystemResponse.ReadOnly =
    zio.aws.storagegateway.model.DisassociateFileSystemResponse
      .wrap(buildAwsValue())
}
object DisassociateFileSystemResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.storagegateway.model.DisassociateFileSystemResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.storagegateway.model.DisassociateFileSystemResponse =
      zio.aws.storagegateway.model.DisassociateFileSystemResponse(
        fileSystemAssociationARN.map(value => value)
      )
    def fileSystemAssociationARN: Optional[FileSystemAssociationARN]
    def getFileSystemAssociationARN
        : ZIO[Any, AwsError, FileSystemAssociationARN] = AwsError
      .unwrapOptionField("fileSystemAssociationARN", fileSystemAssociationARN)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.storagegateway.model.DisassociateFileSystemResponse
  ) extends zio.aws.storagegateway.model.DisassociateFileSystemResponse.ReadOnly {
    override val fileSystemAssociationARN: Optional[FileSystemAssociationARN] =
      zio.aws.core.internal
        .optionalFromNullable(impl.fileSystemAssociationARN())
        .map(value =>
          zio.aws.storagegateway.model.primitives
            .FileSystemAssociationARN(value)
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.storagegateway.model.DisassociateFileSystemResponse
  ): zio.aws.storagegateway.model.DisassociateFileSystemResponse.ReadOnly =
    new Wrapper(impl)
}
